@@ -67,7 +67,7 @@ class GreyKite(BaseModel):
     def __init__(self):
         """Initializes greykite model"""
         super().__init__()
-        self.__name__ = "greykite"
+        self.__name__ = "GreyKite"
         self.metadata = MetadataParam(
             time_col=DATE_COLUMN_NAME,
             value_col=VALUE_COLUMN_NAME)
@@ -115,7 +115,7 @@ class FBProphet(BaseModel):
     def __init__(self):
         """Initializes prophet model"""
         super().__init__()
-        self.__name__ = "prophet"
+        self.__name__ = "FBProphet"
 
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str, forecast_period_list: list) -> tuple:
         """Runs rolling prediction using the model to return actual and predicted values
@@ -129,7 +129,7 @@ class FBProphet(BaseModel):
         df = dataframe.rename(columns={DATE_COLUMN_NAME: "ds", VALUE_COLUMN_NAME: "y"})
 
         model = Prophet(yearly_seasonality=20)
-        model.fit(df, iter=100)
+        model.fit(df, iter=10000)
 
         future = model.make_future_dataframe(periods=len(forecast_period_list), freq=frequency)
         forecast = model.predict(future)
@@ -147,7 +147,7 @@ class Naive(BaseModel):
     def __init__(self):
         """Initializes naive model"""
         super().__init__()
-        self.__name__ = "naive"
+        self.__name__ = "Naive"
         self.growth_comparison_period_in_years = 1
         self.minimum_training_years = 2
 
@@ -268,7 +268,7 @@ class XGBoost(BaseModel):
     def __init__(self):
         """Initializes xgboost model"""
         super().__init__()
-        self.__name__ = "xgboost"
+        self.__name__ = "XGBoost"
 
     def create_time_series_features(self, time_series_df, frequency, backtest=False):
         result_df = time_series_df.copy()
@@ -403,7 +403,7 @@ class RandomForest(BaseModel):
     def __init__(self):
         """Initializes random forest model"""
         super().__init__()
-        self.__name__ = "randomforest"
+        self.__name__ = "RandomForest"
 
     def create_time_series_features(self, time_series_df, frequency, backtest=False):
         result_df = time_series_df.copy()
@@ -421,9 +421,12 @@ class RandomForest(BaseModel):
         for ii in range(1, previous_periods):
             # Create recent lag periods
             result_df[f"{VALUE_COLUMN_NAME}_{ii}"] = time_series_df[VALUE_COLUMN_NAME].shift(ii)
-        result_df.dropna(inplace=True)
         period_indexes = pd.get_dummies(result_df.period_number)
-        dataframe = pd.concat([result_df, period_indexes], axis=1).drop(columns=["period_number"])
+        mask = True
+        for column in result_df.columns:
+            mask = mask & (~result_df[column].isnull())
+        dataframe = pd.merge(left=result_df, right=period_indexes, how="left", left_index=True, right_index=True)
+        dataframe = dataframe[mask]
 
         return dataframe
 
@@ -500,6 +503,8 @@ class RandomForest(BaseModel):
 
         # Prepare dataframe
         dataframe_backtest = self.create_time_series_features(dataframe, frequency, backtest=True)
+        print(dataframe_backtest.head(3).T)
+        print(dataframe_backtest.columns)
 
         predicted = []
         # Split into train and test
@@ -536,7 +541,7 @@ class SARIMA(BaseModel):
     def __init__(self):
         """Initializes SARIMA model"""
         super().__init__()
-        self.__name__ = "sarima"
+        self.__name__ = "SARIMA"
 
     def run(self, dataframe: pd.DataFrame, train_end: datetime, frequency: str, forecast_period_list: list) -> tuple:
         dataframe = dataframe.copy()
